/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, {1} của {2}"

, "Recurrances"
: "Lặp lại"

, "No recurring rule defined"
: "Không định nghĩa quy tắc lặp lại"

, "Details"
: "Chi tiết"

, "None"
: "Không"

, "Daily"
: "Hàng ngày"

, "Weekly"
: "Hàng tuần"

, "Monthly"
: "Hàng tháng"

, "Yearly"
: "Hàng năm"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Trừ sự kiện lặp lại không thể tự có sự kiện lặp lại"

, "at"
: "tại"

, "never"
: "Không bao giờ"

, "after {0} occurrences"
: "sau {0} lần diễn ra"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Kết thúc"

, "Until has to be after event start"
: "Cho tới khi sự kiện bắt đaafu"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "Mỗi {0}. Ngày"

, "Every {0}. Week at"
: "Mỗi {0}. Tuần"

, "Every {0}. Month"
: "Mỗi {0}. Tháng"

, "at the"
: "tại"

, "first"
: "đầu tiên"

, "second"
: "thứ hai"

, "third"
: "thứ ba"

, "fourth"
: "thứ tư"

, "last"
: "cuối"

, "Every {0}. Year"
: "Mỗi {0}. Năm"

, "of"
: "của"

, "Summary"
: "Tóm tắt"

, "Organizer"
: "Tổ chức"

, "Description"
: "Mô tả"

, "Location"
: "Địa điểm"

, "Start Time"
: "Thời gian bắt đầu"

, "End Time"
: "Thời gian kết thúc"

, "Attendee"
: "Người tham dự"

, "whole day"
: "cả ngày"

, "Week {0} :"
: "Tuần {0}:"

, "Poll, Polls"
: [
  ""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Tạo sự kiện"

, "Calendar, Calendars"
: [
  "one:Lịch\nother:Lịch"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "Thêm người tham dự"

, "Sort Attendee"
: ""

, "Check to filter for this attendee"
: ""

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Đang tải sự kiện, xin đợi trong giây lát..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "In trang"

, "Loose-Leaf"
: ""

, "Sheet"
: "Ô"

, "Grid"
: "Lưới"

, "Timeline"
: ""

, "Day"
: "Ngày"

, "Week"
: "Tuần"

, "Month"
: "Tháng"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: "Đặt câu trả lời của tôi"

, "Copy {0}"
: "Sao chép {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Cập nhật sự kiện trong quá khứ"

, "Update this event"
: "Cập nhật sự kiện này"

, "Do not update this event"
: "Không nhân bản được sự kiện này"

, "Creating event in the past"
: "Tạo sự kiện trong quá khứ"

, "Create this event"
: "Tạo sự kiện này"

, "Do not create this event"
: "Không tạo sự kiện này"

, "Update this event only"
: "Chỉ cập nhật sự kiện này"

, "Update this and all future events"
: "Cập nhật sự kiện này và trong tương lai"

, "Update whole series"
: "Cập nhập toàn bộ chuỗi"

, "Update nothing"
: "Không cập nhật gì"

, "Update Event"
: "Cập nhật sự kiện"

, "Please Change Selection"
: "Xin hãy thay đổi lựa chọn"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Lựa chọn của bạn chứa sự kiện lặp lại. Sự kiện lặp lại có thể bị xóa độc lập!"

, "Delete Event"
: "Xóa sự kiện"

, "Delete this event only"
: "Chỉ xóa sự kiện này"

, "Delete this and all future events"
: "Xóa sự kiện này và mọi sự kiện trong tương lai"

, "Delete whole series"
: "Xóa toàn bộ chuỗi sự kiện"

, "Delete nothing"
: "Không xóa gì"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "one: Bạn có muốn xóa sự kiện này\nother: Bạn có muốn xóa các sự kiện đã chọn {0}"

]
, "Could not Print"
: "Không thể in"

, "Sorry, your current view does not support printing."
: "Xin lỗi, màn hình hiện tại không hỗ trợ việc in ấn"

, "Scheduling Conflict"
: "Xung đột lịch"

, "The following attendee are busy at the requested time:"
: "Người tham dự sau bận tại thời điểm yêu cầu:"

, "Ignore Conflict"
: "Bỏ qua xung đột"

, "Edit Event"
: "Sửa sự kiện"

, "Cancel this action"
: "Hủy hành động này"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Quản lý tài nguyên"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Chọn người tham dự"

, "Attachments"
: ""

, "Private"
: "Riêng tư"

, "Tags"
: "Thẻ"

, "Blocking"
: "Ngăn chặn"

, "Tentative"
: "Phân vân"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "phân loại cá nhân"

, "recurring event"
: "sự kiện lặp lại"

, "recurring event exception"
: "ngoại trừ sự kiện lặp lại"

, "has alarm"
: "có nhắc việc"

, "has attachments"
: ""

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Lịch rút gọn"

, "WK"
: "WK"

, "{0} more..."
: "{0} thêm..."

, "Resource Grant, Resource Grants"
: [
  ""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Xin chọn sự kiện để thêm liên hệ vào đó"

, "Role"
: "Vai trò"

, "Select Role"
: "Chọn vai trò"

, "Status"
: "Trạng thái"

, "Select Status"
: "Chọn trạng thái"

, "Adding {0} Attendee to event"
: "Thêm người tham gia {0} vào sự kiện"

, "no events found"
: "không thấy sự kiện nào"

, "Searching..."
: "Đang tìm"

, "Search Event"
: "Tìm sự kiện"

, "Event, Events"
: [
  "one: Sự kiện\nother: Sự kiện"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "không chặn"

, "Displayed in"
: ""

, "No Information"
: "Không có thông tin"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Sự kiện"

, "Calendars"
: "Lịch"

, "Quick Search"
: "Tìm nhanh"

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Trạng thái tham dự"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Vai trò tham dự"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Phân loại"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: ""

, "{0} {1} o'clock"
: "{0} {1} giờ"

, "Event (as attendee)"
: "Sự kiện (như là người tham dự)"

, "Event (as organizer)"
: "Sự kiện (như là tổ chức)"

, "Event attendee"
: "Thành phần tham dự"

, "Attender, Attendee"
: [
  "one: Người tham dự\nother: Người tham dự"

]
, "Resource, Resources"
: [
  "one: Tài nguyên\nother:Tài nguyên"

]
, "Resources"
: "Tài nguyên"

, "Anyone"
: ""

, "Name"
: "Tên"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "Email"

, "Maximum number of attendee"
: ""

, "Type"
: "Loại"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Click vào đây để mời người tham dự khác"

, "User"
: "Người dùng"

, "Group"
: "Nhóm"

, "Member of group"
: "Thành viên trong nhóm"

, "This is the calendar where the attender has saved this event in"
: "Đây là lịch mà người tham dự đã lưu trong sự kiện này ở"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Xóa người tham dự"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(là 1 thành viên nhóm)"

, "External Attendee"
: ""

, "Originally"
: "Gốc"

, "Checking Calendar Data..."
: "Đang kiểm tra dữ liệu lịch..."

, "Reply to Recurring Event"
: "Trả lời sự kiện lặp lại"

, "You are responding to an recurring event. What would you like to do?"
: "Bạn đang trả lời sự kiện lặp lại. Bạn muốn làm gì?"

, "Respond to whole series"
: "Trả lời toàn bộ chuỗi sự kiện"

, "Do not respond"
: "Không trả lời"

, "The event of this message does not exist"
: "Sự kiện của tin nhắn này không tồn tại"

, "The sender is not authorised to update the event"
: "Người gửi không có quyền cập nhật sự kiện"

, "This message is already processed"
: "Tin nhắn đã được xử lý rồi"

, "You are not an attendee of this event"
: "Bạn không phải là người tham gia sự kiện này"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "Tin nhắn không được hỗ trợ"

, "This is an event invitation for someone else."
: "Đây là 1 lời mời từ ai đó"

, "You have already replied to this event invitation."
: "Bạn đã trả lời lời mời tham gia sự kiện này"

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "Bạn đã nhận 1 lời mời. Đặt câu trả lời tới:"

, "An invited attendee responded to the invitation."
: "Người tham d được mời đã trả lời lời mời"

, "Unsupported method"
: "Phương pháp không được hỗ trợ"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Nhập mô tả"

, "Grants"
: ""

, "This event is originally stored in a calendar you don't have access to."
: "Sự kiện này được lưu ban đầu ở lịch bạn không có quyền truy cập"

, "This event is originally stored in {0}"
: "Sự kiện này được lưu ban đầu ở {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Sự kiện này đồng thời hiển thị trong lịch cá nhân của bạn {0}"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Xem"

, "Saved in"
: "Lưu trong"

, "Enter description"
: "Nhập mô tả"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "Ngày kết thúc không hợp lệ"

, "End date must be after start date"
: "Ngày kết thúc phải sau ngày bắt đầu"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "Ngày bắt đầu không hợp lệ"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "Tóm tắt không được dài hơn 255 ký tự"

, "The summary must have at least 1 character."
: "Tóm tắt phải có ít nhất 1 ký tự"

, "Summary too Long"
: "Tóm tắt quá dài"

, "Summary too Short"
: "Tóm tắt quá ngắn"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Tất cả sự kiện của tôi"

, "Position on the left time axis, day and week view should start with"
: "Vị trí trên trục thời gian còn lại, kiểu xem ngày và tuần bắt đầu"

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Lịch mặc định"

, "The default calendar for invitations and new events"
: "Lịch mặc định cho lời mời và sự kiện mới"

, "Default Favorite"
: "Lối tắt mặc định"

, "The default favorite which is loaded on calendar startup"
: "Lối tắt mặc định được nạp khi lịch khởi động"

, "Get Notification Emails"
: "Tải email thông báo"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "Mức độ hoạt động bạn muốn được thông báo. Xin hãy ghi nhớ rằng tổ chức nhận thông báo cho mọi cập nhật bao gồm người tham gia trả lời trừ khi thiết lập được đặt là \"Không bao giờ\""

, "Send Notifications Emails of own Actions"
: "Gửi email thông báo tới chức năng của chính người sở hữu"

, "Get notifications emails for actions you did yourself"
: "Nhận email thông báo cho chức năng của chính bạn"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Mở tính năng cảnh báo chuẩn"

, "New events get a standard alarm as defined below"
: "Sự kiện mới có nhắc việc chuẩn như được định nghĩa dưới đây"

, "Standard Alarm Time"
: "Thời gian nhắc việc chuẩn"

, "Minutes before the event starts"
: "Số phút trước khi sự kiện xảy ra"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Lịch cố định"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Không bao giờ"

, "On invitation and cancellation only"
: "Chỉ khi có lời mời và hủy bỏ"

, "On time changes"
: "Chỉ khi thời gian thay đổi"

, "On all updates but attendee responses"
: "Khi có mọi cập nhật trừ trả lời của người tham gia"

, "On attendee responses too"
: "Cả khi người tham gia trả lời"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Lịch luôn được chọn không phụ thuộc vào bất kỳ bộ lọc nào. Trường hợp sử dụng hợp lệ có thể buộc hiển thị 1 lịch nghỉ."

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Trạng thái người tham dự sẵn sàng "

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Không trả lời"

, "Accepted"
: "Chấp nhận"

, "Declined"
: "Từ chối"

, "Attendee Roles Available"
: "Trạng thái vai trò người tham dự sẵn sàng"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Bắt buộc"

, "Optional"
: "Tùy chọn"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: ""

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "lịch cá nhân của %s'"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "không rõ"

, "This contact has been automatically added by the system as an event attender"
: "Liên hệ này đã tự động được thêm vào hệ thống như người tham gia sự kiện"

, "The email address has been shortened:"
: ""

, "Every %s day"
: ""

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: ""

, "Monthly every %1$s %2$s"
: ""

, "Every %1$s month on the %2$s"
: ""

, "Monthly on the %1$s"
: ""

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: ""

, "second to last"
: ""

, "fifth"
: ""

, "st"
: ""

, "nd"
: ""

, "rd"
: ""

, "th"
: ""

, "Start"
: "Bắt đầu"

, "Priority"
: "Quan trọng"

, "Url"
: "URL"

, "Recurrance rule"
: "Quy tắc lặp lại"

, "Is all day event"
: "Sự kiện hàng ngày"

, "Organizer timezone"
: "Múi giờ tổ chức"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Nhắc cho sự kiện  \"%1$s\" tại %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Mời tham dự sự kiện \"%1$s\" tại %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "Sự kiện \"%1$s\" tại %2$s đã bị hủy"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Sự kiện \"%1$s\" đã được đặt lại lịch từ %2$s đến %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "Sự kiện \"%1$s\" tại %2$s đã được cập nhật"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s chấp nhận sự kiện \"%2$s\" tại %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s từ chối sự kiện \"%2$s\" tại %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "Trả lời phân vân từ %1$s cho sự kiện \"%2$s\" tại %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Không trả lời từ %1$s cho sự kiện  \"%2$s\" tại %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Người tham dự cho sự kiện  \"%1$s\" tại %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Cập nhật"

, "This is an event series exception."
: ""

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s thay đổi từ \"%2$s\" đến \"%3$s\""

, "%1$s has been invited"
: "%1$s đã được mời"

, "%1$s has been removed"
: "%1$s đã bị xóa"

, "%1$s accepted invitation"
: "%1$s chấp nhận lời mời"

, "%1$s declined invitation"
: "%1$s từ chối lời mời"

, "Tentative response from %1$s"
: "Trả lời phân vân từ %1$s"

, "No response from %1$s"
: "Không trả lời từ %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" trả lời từ %1$s"

, "Link"
: ""

, "Event details"
: "Chi tiết sự kiện"

, "All events I attend"
: "Mọi sự kiện tôi tham gia"

, "Awaiting response"
: "Chờ trả lời"

, "Events I have not yet responded to"
: "Sự kiện tôi chưa trả lời"

, "Declined events"
: "Sự kiện bị từ chối"

, "Events I have declined"
: "Sự kiện tôi đã từ chối"

, "I'm organizer"
: "Tôi là người tổ chức"

, "Events I'm the organizer of"
: "Sự kiện mà tôi là người tổ chức của"

, "manage shared calendars"
: "Quản lý lịch dùng chung"

, "Create new shared calendars"
: "Tạo lịch dùng chung"

, "manage shared calendars favorites"
: "quản lý lối tắt lịch dùng chung"

, "Create or update shared calendars favorites"
: "Tạo, cập nhật lỗi tắt lịch dùng chung"

, "manage resources"
: "Quản lý tài nguyên"

, "All Rights to administrate resources"
: "Tất cả quyền để quản lý tài nguyên"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""

]
, "Poll"
: ""

, "Calendar"
: "one:Lịch\nother:Lịch"

, "Do you really want to delete this event?"
: "one: Bạn có muốn xóa sự kiện này\nother: Bạn có muốn xóa các sự kiện đã chọn {0}"

, "Resource Grant"
: ""

, "Event"
: "one: Sự kiện\nother: Sự kiện"

, "Attender"
: "one: Người tham dự\nother: Người tham dự"

, "Resource"
: "one: Tài nguyên\nother:Tài nguyên"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
